PgCommandSync

Type Alias PgCommandSync 

pub type PgCommandSync = Box<Cell<Command>>;
Synchronous pg_ctl command type.

Cell provides interior mutability so the synchronous pg_ctl stop command can be configured and spawned inside the Drop implementation without requiring a mutable reference to the surrounding struct.

Aliased Type

pub struct PgCommandSync(/* private fields */);