Struct pg_embed::pg_access::PgAccess [−][src]
pub struct PgAccess {
pub cache_dir: PathBuf,
pub database_dir: PathBuf,
pub pg_ctl_exe: PathBuf,
pub init_db_exe: PathBuf,
pub pw_file_path: PathBuf,
pub zip_file_path: PathBuf,
}Expand description
Access to pg_ctl, initdb, database directory and cache directory
Fields
cache_dir: PathBufCache directory path
database_dir: PathBufDatabase directory path
pg_ctl_exe: PathBufPostgresql pg_ctl executable path
init_db_exe: PathBufPostgresql initdb executable path
pw_file_path: PathBufPassword file path
zip_file_path: PathBufPostgresql binaries zip file path
Implementations
pub async fn new(
fetch_settings: &PgFetchSettings,
database_dir: &PathBuf
) -> Result<Self, PgEmbedError>
pub async fn new(
fetch_settings: &PgFetchSettings,
database_dir: &PathBuf
) -> Result<Self, PgEmbedError>Create a new instance
Directory structure for cached postgresql binaries will be created
Check if postgresql executables are already cached
Check if database directory exists
Write pg binaries zip to postgresql cache directory
Clean up created files and directories.
Remove created directories containing the database and the password file.
Create a database password file
Returns Ok(()) on success, otherwise returns an error.
pub fn init_db_command(
&self,
database_dir: &PathBuf,
user: &str,
auth_method: &PgAuthMethod
) -> Box<Cell<Command>>
pub fn init_db_command(
&self,
database_dir: &PathBuf,
user: &str,
auth_method: &PgAuthMethod
) -> Box<Cell<Command>>Create initdb command
Create pg_ctl start command